%
% Test script to run a set of example systems with HINORM.
%
% The example data can be downloaded from
%
%    https://sites.google.com/site/rommes/software; and
%    http://www.slicot.org/index.php?site=benchmodred.
%
% REFERENCES:
%
% [1] P. Benner and M. Voigt:
%     A structured pseudospectral method for H-infinity-norm computation of 
%     large-scale descriptor systems, 2012.
%
% AUTHOR:
%
% Matthias Voigt, Max Planck Institute for Dynamics of Complex Technical
% Systems, Magdeburg, Germany, 06/25/2013.
%
% REVISIONS:
%
% -
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  HINORM 1.0 Copyright (C) 2013 Matthias Voigt 
%
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
diary( 'diary.dia' );
fprintf( '===========================================================\n' );
fprintf( 'TEST SERIES FOR HINORM v1.0\n' );
fprintf( '===========================================================\n' );
fprintf( 'Date: %s.\n', date );
fprintf( 'Version: %s.\n', version );
clear
%% EXAMPLE 1
load build
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 1: build\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( speye( 48 ), A, sparse( B ), ...
    sparse( C ), 0, options );
%% EXAMPLE 2
clear
load pde
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 2: pde\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( speye( 84 ), A, B, C, 0, options );
%% EXAMPLE 3
clear
load CDplayer
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 3: CDplayer\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( speye( 120 ), A, sparse( B ), ...
    sparse( C ), zeros( 2 ), options );
%% EXAMPLE 4
clear
load iss
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 4: iss\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( speye( 270 ), A, B, C, zeros( 3 ), ...
    options );
%% EXAMPLE 5
clear
load beam
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 5: beam\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( speye( 348 ), A, sparse( B ), ...
    sparse( C ), 0, options );
%% EXAMPLE 6
clear
load S10PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 6: S10PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 7
clear
load S20PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 7: S20PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 8
clear
load S40PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 8: S40PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 9
clear
load S80PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 9: S80PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 10
clear
load M10PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 10: M10PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 11
clear
load M20PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 11: M20PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 12
clear
load M40PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 12: M40PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 13
clear
load M80PI_n1
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 13: M80PI_n1\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 14
clear
load peec
options.npolinit = 40;
options.npolin = 10;
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 14: peec\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, B, C, 0, options );
%% EXAMPLE 15
clear
load S10PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 15: S10PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 16
clear
load S20PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 16: S20PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 17
clear
load S40PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 17: S40PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 18
clear
load S80PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 18: S80PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, 0, options );
%% EXAMPLE 19
clear
load M10PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 19: M10PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 20
clear
load M20PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 20: M20PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 21
clear
load M40PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 21: M40PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 22
clear
load M80PI_n
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 22: M80PI_n\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( T, A, B, C, zeros( 3 ), options );
%% EXAMPLE 23
clear
load bips98_606
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 23: bips98_606\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 24
clear
load bips98_1142
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 24: bips98_1142\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 25
clear
load bips98_1450
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 25: bips98_1450\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 26
clear
load bips07_1693
options.npolinit = 30;
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 26: bips07_1693\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 27
clear
load bips07_1998
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 27: bips07_1998\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 28
clear
load bips07_2476
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 28: bips07_2476\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 29
clear
load bips07_3078
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 29: bips07_3078\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c, zeros( 4 ), options );
%% EXAMPLE 30
clear
load xingo_afonso_itaipu
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 30: xingo_afonso_itaipu\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, B, C', 0, options );
%% EXAMPLE 31
clear
load mimo8x8_system
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 31: mimo8x8_system\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c', zeros( 8 ), options );
%% EXAMPLE 32
clear
load mimo28x28_system
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 32: mimo28x28_system\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, b, c', zeros( 28 ), options );
%% EXAMPLE 33
clear
load mimo46x46_system
options.psabschk = 1;
options.prtlevel = 2;
fprintf( '===========================================================\n' );
fprintf( 'Example 33: mimo46x46_system\n' );
fprintf( '===========================================================\n' );
[ normval, fopt, info ] = hinorm( E, A, B, C', zeros( 46 ), options );
%%
diary off